"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CorepackExecutor = void 0;
const execa_1 = require("execa");
const node_path_1 = __importDefault(require("node:path"));
/**
 * Disables the strict `packageManager` field in `package.json`.
 *
 * If this field was enabled, then `corepack` would not arbitrarily run
 * user-requested package manager & version pairs.
 */
const DEFAULT_ENV = {
    COREPACK_ENABLE_PROJECT_SPEC: '0',
};
/**
 * An {@linkcode Executor} which executes `corepack`.
 *
 * @see {@link https://github.com/nodejs/corepack}
 */
class CorepackExecutor {
    /**
     * @param pmId The package manager ID (`<npm|yarn|pnpm>@<version>`) to use as the first argument to `corepack`.
     */
    constructor(pmId) {
        this.pmId = pmId;
        this.corepackPath = node_path_1.default.resolve(node_path_1.default.dirname(require.resolve('corepack/package.json')), '..', '.bin', 'corepack');
    }
    async exec(args, execaOpts = {}, execOpts = {}) {
        const proc = (0, execa_1.node)(this.corepackPath, [this.pmId, ...args], {
            env: { ...DEFAULT_ENV, ...execaOpts.env },
            ...execaOpts,
        });
        if (execOpts.verbose) {
            proc.stdout?.pipe(process.stdout);
            proc.stderr?.pipe(process.stderr);
        }
        return await proc;
    }
}
exports.CorepackExecutor = CorepackExecutor;
//# sourceMappingURL=corepack.js.map