import createDebug from 'debug';
import type { SemVer } from 'semver';
import type { InstallManifest } from '../types';
import type { CorepackExecutor } from './corepack';
import { GenericNpmPackageManager } from './npm';
import type { InstallResult, PackOpts, PackageManager, PackageManagerOpts } from './pm';
/**
 * Type of item in the {@linkcode NpmPackItem.files} array.
 * @internal
 */
export interface NpmPackItemFileEntry {
    mode: number;
    path: string;
    size: number;
}
/**
 * JSON output of `npm pack`
 * @internal
 */
export interface NpmPackItem {
    bundled: any[];
    entryCount: number;
    filename: string;
    files: NpmPackItemFileEntry[];
    id: string;
    integrity: string;
    name: string;
    shasum: string;
    size: number;
    unpackedSize: number;
    version: string;
}
export declare class Npm7 extends GenericNpmPackageManager implements PackageManager {
    protected debug: createDebug.Debugger;
    static readonly bin = "npm";
    readonly name = "npm";
    constructor(executor: CorepackExecutor, opts?: PackageManagerOpts);
    static accepts(semver: SemVer): boolean;
    static load(executor: CorepackExecutor, opts?: PackageManagerOpts): Npm7;
    install(manifest: InstallManifest): Promise<InstallResult>;
    pack(dest: string, opts?: PackOpts): Promise<InstallManifest>;
}
declare const _default: typeof Npm7;
export default _default;
//# sourceMappingURL=npm7.d.ts.map