"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initPMLoader = void 0;
const debug_1 = __importDefault(require("debug"));
const error_1 = require("../error");
const corepack_1 = require("./corepack");
const version_1 = require("./version");
const debug = (0, debug_1.default)('midnight-smoker:pm:loader');
function initPMLoader(builtinPms = []) {
    return async function loadPackageManagers(pms = ['npm'], opts = {}) {
        const nameVersionPairs = await Promise.all(pms.map(async (pm) => {
            const [name, version] = pm.split('@');
            return [name, await (0, version_1.normalizeVersion)(name, version)];
        }));
        debug('Requested package managers: %O', nameVersionPairs.flatMap(([name, version]) => `${name}@${version}`));
        const toLoad = nameVersionPairs.reduce((acc, [name, version]) => {
            const pmm = builtinPms.find((pmm) => pmm.bin === name && pmm.accepts(version));
            if (!pmm) {
                throw new error_1.UnsupportedPackageManagerError(`No package manager found that can handle ${name}@${version}`, name, version.toString());
            }
            acc.set(`${name}@${version}`, pmm);
            return acc;
        }, new Map());
        debug('Loading package managers: %O', [...toLoad.keys()]);
        const pmMap = new Map();
        for await (const [id, pmm] of toLoad) {
            pmMap.set(id, await pmm.load(new corepack_1.CorepackExecutor(id), opts));
        }
        // TODO: throw if we can't find one that will handle the request
        return pmMap;
    };
}
exports.initPMLoader = initPMLoader;
//# sourceMappingURL=pm-loader.js.map