import { z } from 'zod';
/**
 * Default options for rule behavior (the `rules` prop in `SmokerOptions`).
 *
 * Dynamically created by each rule's `defaultOptions` property.
 *
 * @internal
 */
export declare const DEFAULT_CHECK_OPTIONS: {
    readonly "no-missing-pkg-files": {
        bin: boolean;
        browser: boolean;
        types: boolean;
        unpkg: boolean;
        module: boolean;
        fields: string[];
    };
    readonly "no-banned-files": {
        allow: string[];
        deny: string[];
    };
    readonly "no-missing-entry-point": any;
    readonly "no-missing-exports": {
        types: boolean;
        require: boolean;
        import: boolean;
        order: boolean;
        glob: boolean;
    };
};
/**
 * @internal
 */
export declare const zCheckOptions: z.ZodDefault<z.ZodObject<{
    "no-banned-files": z.ZodUnion<[z.ZodEffects<z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>, {
        severity: "error" | "warn" | "off";
        opts: {
            allow: string[];
            deny: string[];
        };
    }, "error" | "warn" | "off" | undefined>, z.ZodEffects<z.ZodObject<{
        allow: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
        deny: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        allow: string[];
        deny: string[];
    }, {
        allow?: string[] | undefined;
        deny?: string[] | undefined;
    }>, {
        severity: "error" | "warn" | "off";
        opts: any;
    }, {
        allow?: string[] | undefined;
        deny?: string[] | undefined;
    }>, z.ZodEffects<z.ZodTuple<[z.ZodObject<{
        allow: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
        deny: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        allow: string[];
        deny: string[];
    }, {
        allow?: string[] | undefined;
        deny?: string[] | undefined;
    }>, z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>], null>, {
        severity: "error" | "warn" | "off";
        opts: {
            allow: string[];
            deny: string[];
        };
    }, [{
        allow?: string[] | undefined;
        deny?: string[] | undefined;
    }, "error" | "warn" | "off" | undefined]>]>;
    "no-missing-pkg-files": z.ZodUnion<[z.ZodEffects<z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>, {
        severity: "error" | "warn" | "off";
        opts: {
            bin: boolean;
            browser: boolean;
            types: boolean;
            unpkg: boolean;
            module: boolean;
            fields: string[];
        };
    }, "error" | "warn" | "off" | undefined>, z.ZodEffects<z.ZodObject<{
        bin: z.ZodDefault<z.ZodBoolean>;
        browser: z.ZodDefault<z.ZodBoolean>;
        types: z.ZodDefault<z.ZodBoolean>;
        unpkg: z.ZodDefault<z.ZodBoolean>;
        module: z.ZodDefault<z.ZodBoolean>;
        fields: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        bin: boolean;
        browser: boolean;
        types: boolean;
        unpkg: boolean;
        module: boolean;
        fields: string[];
    }, {
        bin?: boolean | undefined;
        browser?: boolean | undefined;
        types?: boolean | undefined;
        unpkg?: boolean | undefined;
        module?: boolean | undefined;
        fields?: string[] | undefined;
    }>, {
        severity: "error" | "warn" | "off";
        opts: any;
    }, {
        bin?: boolean | undefined;
        browser?: boolean | undefined;
        types?: boolean | undefined;
        unpkg?: boolean | undefined;
        module?: boolean | undefined;
        fields?: string[] | undefined;
    }>, z.ZodEffects<z.ZodTuple<[z.ZodObject<{
        bin: z.ZodDefault<z.ZodBoolean>;
        browser: z.ZodDefault<z.ZodBoolean>;
        types: z.ZodDefault<z.ZodBoolean>;
        unpkg: z.ZodDefault<z.ZodBoolean>;
        module: z.ZodDefault<z.ZodBoolean>;
        fields: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
    }, "strip", z.ZodTypeAny, {
        bin: boolean;
        browser: boolean;
        types: boolean;
        unpkg: boolean;
        module: boolean;
        fields: string[];
    }, {
        bin?: boolean | undefined;
        browser?: boolean | undefined;
        types?: boolean | undefined;
        unpkg?: boolean | undefined;
        module?: boolean | undefined;
        fields?: string[] | undefined;
    }>, z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>], null>, {
        severity: "error" | "warn" | "off";
        opts: {
            bin: boolean;
            browser: boolean;
            types: boolean;
            unpkg: boolean;
            module: boolean;
            fields: string[];
        };
    }, [{
        bin?: boolean | undefined;
        browser?: boolean | undefined;
        types?: boolean | undefined;
        unpkg?: boolean | undefined;
        module?: boolean | undefined;
        fields?: string[] | undefined;
    }, "error" | "warn" | "off" | undefined]>]>;
    "no-missing-entry-point": z.ZodUnion<[z.ZodEffects<z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>, {
        severity: "error" | "warn" | "off";
        opts: any;
    }, "error" | "warn" | "off" | undefined>, z.ZodEffects<z.ZodAny, {
        severity: "error" | "warn" | "off";
        opts: any;
    }, any>, z.ZodEffects<z.ZodTuple<[z.ZodAny, z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>], null>, {
        severity: "error" | "warn" | "off";
        opts: any;
    }, [any, "error" | "warn" | "off" | undefined]>]>;
    "no-missing-exports": z.ZodUnion<[z.ZodEffects<z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>, {
        severity: "error" | "warn" | "off";
        opts: {
            types: boolean;
            require: boolean;
            import: boolean;
            order: boolean;
            glob: boolean;
        };
    }, "error" | "warn" | "off" | undefined>, z.ZodEffects<z.ZodObject<{
        types: z.ZodDefault<z.ZodBoolean>;
        require: z.ZodDefault<z.ZodBoolean>;
        import: z.ZodDefault<z.ZodBoolean>;
        order: z.ZodDefault<z.ZodBoolean>;
        glob: z.ZodDefault<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        types: boolean;
        require: boolean;
        import: boolean;
        order: boolean;
        glob: boolean;
    }, {
        types?: boolean | undefined;
        require?: boolean | undefined;
        import?: boolean | undefined;
        order?: boolean | undefined;
        glob?: boolean | undefined;
    }>, {
        severity: "error" | "warn" | "off";
        opts: any;
    }, {
        types?: boolean | undefined;
        require?: boolean | undefined;
        import?: boolean | undefined;
        order?: boolean | undefined;
        glob?: boolean | undefined;
    }>, z.ZodEffects<z.ZodTuple<[z.ZodObject<{
        types: z.ZodDefault<z.ZodBoolean>;
        require: z.ZodDefault<z.ZodBoolean>;
        import: z.ZodDefault<z.ZodBoolean>;
        order: z.ZodDefault<z.ZodBoolean>;
        glob: z.ZodDefault<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        types: boolean;
        require: boolean;
        import: boolean;
        order: boolean;
        glob: boolean;
    }, {
        types?: boolean | undefined;
        require?: boolean | undefined;
        import?: boolean | undefined;
        order?: boolean | undefined;
        glob?: boolean | undefined;
    }>, z.ZodDefault<z.ZodDefault<z.ZodEnum<["off", "warn", "error"]>>>], null>, {
        severity: "error" | "warn" | "off";
        opts: {
            types: boolean;
            require: boolean;
            import: boolean;
            order: boolean;
            glob: boolean;
        };
    }, [{
        types?: boolean | undefined;
        require?: boolean | undefined;
        import?: boolean | undefined;
        order?: boolean | undefined;
        glob?: boolean | undefined;
    }, "error" | "warn" | "off" | undefined]>]>;
}, "strip", z.ZodTypeAny, {
    "no-banned-files": ({
        severity: "error" | "warn" | "off";
        opts: {
            allow: string[];
            deny: string[];
        };
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: {
            allow: string[];
            deny: string[];
        };
    }) & ({
        severity: "error" | "warn" | "off";
        opts: {
            allow: string[];
            deny: string[];
        };
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: {
            allow: string[];
            deny: string[];
        };
    } | undefined);
    "no-missing-pkg-files": ({
        severity: "error" | "warn" | "off";
        opts: {
            bin: boolean;
            browser: boolean;
            types: boolean;
            unpkg: boolean;
            module: boolean;
            fields: string[];
        };
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: {
            bin: boolean;
            browser: boolean;
            types: boolean;
            unpkg: boolean;
            module: boolean;
            fields: string[];
        };
    }) & ({
        severity: "error" | "warn" | "off";
        opts: {
            bin: boolean;
            browser: boolean;
            types: boolean;
            unpkg: boolean;
            module: boolean;
            fields: string[];
        };
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: {
            bin: boolean;
            browser: boolean;
            types: boolean;
            unpkg: boolean;
            module: boolean;
            fields: string[];
        };
    } | undefined);
    "no-missing-entry-point": ({
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    }) & ({
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | undefined);
    "no-missing-exports": ({
        severity: "error" | "warn" | "off";
        opts: {
            types: boolean;
            require: boolean;
            import: boolean;
            order: boolean;
            glob: boolean;
        };
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: {
            types: boolean;
            require: boolean;
            import: boolean;
            order: boolean;
            glob: boolean;
        };
    }) & ({
        severity: "error" | "warn" | "off";
        opts: {
            types: boolean;
            require: boolean;
            import: boolean;
            order: boolean;
            glob: boolean;
        };
    } | {
        severity: "error" | "warn" | "off";
        opts: any;
    } | {
        severity: "error" | "warn" | "off";
        opts: {
            types: boolean;
            require: boolean;
            import: boolean;
            order: boolean;
            glob: boolean;
        };
    } | undefined);
}, {
    "no-banned-files"?: "error" | "warn" | "off" | {
        allow?: string[] | undefined;
        deny?: string[] | undefined;
    } | [{
        allow?: string[] | undefined;
        deny?: string[] | undefined;
    }, "error" | "warn" | "off" | undefined] | undefined;
    "no-missing-pkg-files"?: "error" | "warn" | "off" | {
        bin?: boolean | undefined;
        browser?: boolean | undefined;
        types?: boolean | undefined;
        unpkg?: boolean | undefined;
        module?: boolean | undefined;
        fields?: string[] | undefined;
    } | [{
        bin?: boolean | undefined;
        browser?: boolean | undefined;
        types?: boolean | undefined;
        unpkg?: boolean | undefined;
        module?: boolean | undefined;
        fields?: string[] | undefined;
    }, "error" | "warn" | "off" | undefined] | undefined;
    "no-missing-entry-point"?: any;
    "no-missing-exports"?: "error" | "warn" | "off" | {
        types?: boolean | undefined;
        require?: boolean | undefined;
        import?: boolean | undefined;
        order?: boolean | undefined;
        glob?: boolean | undefined;
    } | [{
        types?: boolean | undefined;
        require?: boolean | undefined;
        import?: boolean | undefined;
        order?: boolean | undefined;
        glob?: boolean | undefined;
    }, "error" | "warn" | "off" | undefined] | undefined;
}>>;
/**
 * The input type for {@linkcode zCheckOptions}
 * @internal
 */
export type RawCheckOptions = z.input<typeof zCheckOptions>;
/**
 * The parsed and normalized type for {@linkcode zCheckOptions}
 */
export type CheckOptions = z.infer<typeof zCheckOptions>;
//# sourceMappingURL=check-options.d.ts.map