import readPkgUp from 'read-pkg-up';
/**
 * Trims all strings in an array and removes empty strings.
 * Returns empty array if input is falsy.
 */
export declare function normalizeStringArray(value?: string | string[]): string[];
export declare function castArray<T>(value: T | T[]): NonNullable<T>[];
/**
 * Try to pick a version for a package to install.
 *
 * Given an `installable` which is both a) a valid npm package name and b) has
 * no version specifier, determine the version to install.
 *
 * If the `package.json` within `cwd` contains the package of the same name, we
 * will use that version; otherwise we will use the `latest` tag. If
 * `installable` is not a package name at all, it passes thru verbatim.
 *
 * @param installable The `thing` in `npm install <thing>`
 * @param cwd Where the command would be run
 */
export declare function pickPackageVersion(installable: string, cwd?: string): Promise<string>;
/**
 * Options for {@linkcode readPackageJson}
 */
export interface ReadPackageJsonOpts {
    /**
     * Defaults to `process.cwd()`
     */
    cwd?: string;
    /**
     * Normalize the `package.json`
     */
    normalize?: boolean;
    /**
     * Reject if not found
     */
    strict?: boolean;
}
/**
 * Reads closest `package.json` from some dir
 * @param cwd Dir to read from
 * @param Options
 * @returns Object with `packageJson` and `path` properties or `undefined` if not in `strict` mode
 */
export declare function readPackageJson(opts: ReadPackageJsonOpts & {
    strict: true;
}): Promise<readPkgUp.ReadResult>;
export declare function readPackageJson(opts?: ReadPackageJsonOpts): Promise<readPkgUp.ReadResult | undefined>;
export declare namespace readPackageJson {
    var cache: Map<ReadPackageJsonOpts, readPkgUp.ReadResult | undefined>;
}
/**
 * Reads closest `package.json` from some dir (synchronously)
 * @param cwd Dir to read from
 * @param Options
 * @returns Object with `packageJson` and `path` properties or `undefined` if not in `strict` mode
 * @remarks Use {@linkcode readPackageJson} instead if possible
 */
export declare function readPackageJsonSync(opts: ReadPackageJsonOpts & {
    strict: true;
}): readPkgUp.ReadResult;
export declare function readPackageJsonSync(opts?: ReadPackageJsonOpts): readPkgUp.ReadResult | undefined;
export declare namespace readPackageJsonSync {
    var cache: Map<ReadPackageJsonOpts, readPkgUp.ReadResult | undefined>;
}
export declare function findDataDir(): Promise<string>;
//# sourceMappingURL=util.d.ts.map